#include "aktionConf.h"

Setup::Setup( QWidget *parent, const char *name )
    : QDialog( parent, name, TRUE )
{
    int max=320;
    int may=245;

    setFixedSize(max+30,may+60);
    setCaption( i18n("aKtion! Setup" ));

    tab = new KTabCtl( this, "ktab" );
    tab->setGeometry( 3, 0, max+25, may+20 );

    KApplication *app=KApplication::getKApplication();
    config=app->getConfig();

    /* ====================== AUDIO ======================= */
    w[0] = new QWidget( tab, "Audio" );
    config->setGroup("audio");

    checkBox[0] = new QCheckBox( w[0] );
    checkBox[0]->setText( i18n("Audio enable") );
    checkBox[0]->setGeometry(10,10,max,20);
    checkBox[0]->setChecked(config->readBoolEntry("enable"));

    checkBox[1] = new QCheckBox( w[0] );
    checkBox[1]->setText( i18n("Skip frames for audio sync") );
    checkBox[1]->setGeometry(10,30,max,20);
    checkBox[1]->setChecked(config->readBoolEntry("audioSync"));

    checkBox[8] = new QCheckBox( w[0] );
    checkBox[8]->setText( i18n("Show volume slider") );
    checkBox[8]->setGeometry(10,50,max,20);
    checkBox[8]->setChecked(config->readBoolEntry("showVolumeSlider"));

    label[0] = new QLabel( w[0] );
    label[0]->setGeometry(10,70,max,20);
    label[0]->setText( i18n("Initial volume (0-100):" ));
    spin[0] = new KNumericSpinBox( w[0] );
    spin[0]->setRange(0,100);
    spin[0]->setGeometry(10,90,40,22);
    spin[0]->setValue(config->readNumEntry("audioInitialVolume"));

    w[0]->resize( max+10, may );
    tab->addTab( w[0], i18n("Audio" ));

    /* ====================== COLOR ======================= */
    w[1] = new QWidget( tab, "Color" );
    config->setGroup("color");

    grupo[0] = new QGroupBox(w[1]);
    grupo[0]->setGeometry(10,10,max,160);
    grupo[0]->setTitle( i18n("Color mapping (non TrueColor displays)"));
    
    botonRadio[0] = new QRadioButton( grupo[0] );
    botonRadio[0]->setText( i18n("TrueColor to 322 (static color)") );
    botonRadio[0]->setGeometry(10,20,max-20,20);

    botonRadio[1] = new QRadioButton( grupo[0] );
    botonRadio[1]->setText( i18n("Color lookup table") );
    botonRadio[1]->setGeometry(10,40,max-20,20);

    label[1] = new QLabel( grupo[0] );
    label[1]->setGeometry(30,60,max-40,20);
    label[1]->setText( i18n("Numer of frames to look ahead:" ));
    lined[0] = new QLineEdit( grupo[0] );
    lined[0]->setGeometry(30,80,40,20);
    lined[0]->setText(config->readEntry("colorAhead"));

    botonRadio[2] = new QRadioButton( grupo[0] );
    botonRadio[2]->setText( i18n("TrueColor to grayscale") );
    botonRadio[2]->setGeometry(10,110,max-20,20);

    botonRadio[3] = new QRadioButton( grupo[0] );
    botonRadio[3]->setText( i18n("None") );
    botonRadio[3]->setGeometry(10,130,max-20,20);

    botones[0] = new QButtonGroup( w[1] );
    botones[0]->hide();
    botones[0]->insert(botonRadio[0]);
    botones[0]->insert(botonRadio[1]);
    botones[0]->insert(botonRadio[2]);
    botones[0]->insert(botonRadio[3]);
//    botones[0]->setButton(config->readNumEntry("colorMapping"));
    /* patch for Qt 1.32 */
    botonRadio[config->readNumEntry("colorMapping")]->setChecked(true);

    label[2] = new QLabel( w[1] );
    label[2]->setGeometry(10,170,max,20);
    label[2]->setText( i18n("Gamma of display:" ));
    lined[1] = new QLineEdit( w[1] );
    lined[1]->setGeometry(10,190,40,20);
    lined[1]->setText(config->readEntry("gammaDisp"));

    w[1]->resize( max+10, may );
    tab->addTab( w[1], i18n("Color") );

    /* ====================== SCALING ======================= */
    w[2] = new QWidget( tab, "Scaling" );
    config->setGroup("scaling");

    label[3] = new QLabel( w[2] );
    label[3]->setGeometry(10,10,max,20);
    label[3]->setText( i18n("Display scale" ));
    combo[0] = new QComboBox( w[2] );
    combo[0]->setGeometry(10,30,150,20);
    combo[0]->insertItem( i18n("Original size") );
    combo[0]->insertItem( i18n("Half size") );
    combo[0]->insertItem( i18n("Double size") );
    combo[0]->insertItem( i18n("Maximized") );
    combo[0]->setCurrentItem(config->readNumEntry("scale"));

    w[2]->resize( max+10, may );
    tab->addTab( w[2], i18n("Scaling" ));

    /* ====================== OTHERS ======================= */
    w[3] = new QWidget( tab, "Others" );
    config->setGroup("others");

    checkBox[2] = new QCheckBox( w[3] );
    checkBox[2]->setText( i18n("Preload animation into memory") );
    checkBox[2]->setGeometry(10,10,max,20);
    checkBox[2]->setChecked(config->readBoolEntry("preload"));

    checkBox[3] = new QCheckBox( w[3] );
    checkBox[3]->setText( i18n("Use X11 shared memory") );
    checkBox[3]->setGeometry(10,30,max,20);
    checkBox[3]->setChecked(config->readBoolEntry("x11shared"));

    checkBox[4] = new QCheckBox( w[3] );
    checkBox[4]->setText( i18n("Use X11 multi buffering") );
    checkBox[4]->setGeometry(10,50,max,20);
    checkBox[4]->setChecked(config->readBoolEntry("multiBuffer"));

    checkBox[5] = new QCheckBox( w[3] );
    checkBox[5]->setText( i18n("Use Pixmap instead of Image in X11") );
    checkBox[5]->setGeometry(10,70,max,20);
    checkBox[5]->setChecked(config->readBoolEntry("pixmap"));
/*
    label[7] = new QLabel( w[3] );
    label[7]->setGeometry(10,90,max,20);
    label[7]->setText( i18n("X11 Visual of class:" ));
    combo[0] = new QComboBox( w[3] );
    combo[0]->setGeometry(10,110,150,20);
    combo[0]->insertItem("(default)");
    combo[0]->insertItem("Static gray");
    combo[0]->insertItem("Gray scale");
    combo[0]->insertItem("Static color");
    combo[0]->insertItem("Pseudo color");
    combo[0]->insertItem("True color");
    combo[0]->insertItem("Direct color");
    combo[0]->setCurrentItem(config->readNumEntry("visualClass"));
*/
    label[4] = new QLabel( w[3] );
    label[4]->setGeometry(10,90,max,20);
    label[4]->setText( i18n("Initial directory:" ));
    lined[3] = new QLineEdit( w[3] );
    lined[3]->setGeometry(10,110,max-21,20);
    lined[3]->setText( config->readEntry("initialDirectory"));
    dirButton = new QPushButton( w[3] );
    dirButton->setText("...");
    dirButton->setGeometry(10+max-20,110,20,20);
    connect( dirButton, SIGNAL(clicked()), SLOT(getDir()) );    
    
    checkBox[6] = new QCheckBox( w[3] );
    checkBox[6]->setText( i18n("Loop animation") );
    checkBox[6]->setGeometry(10,140,max,20);
    checkBox[6]->setChecked(config->readBoolEntry("loop"));

    checkBox[7] = new QCheckBox( w[3] );
    checkBox[7]->setText( i18n("Automatically start playing video") );
    checkBox[7]->setGeometry(10,160,max,20);
    checkBox[7]->setChecked(config->readBoolEntry("autoplay"));

    label[5] = new QLabel( w[3] );
    label[5]->setGeometry(10,180,max,20);
    label[5]->setText( i18n("Extra XAnim parameters:" ));
    lined[2] = new QLineEdit( w[3] );
    lined[2]->setGeometry(10,200,max,20);
    lined[2]->setText( config->readEntry("extras"));

    w[3]->resize( max+10, may );
    tab->addTab( w[3], i18n("Others" ));

    /* ====================== MIME types ======================= */
/*    w[4] = new QWidget( tab, "Mime" );
    config->setGroup("MIME");
    
    label[9] = new QLabel( w[4] );
    label[9]->setGeometry(10,10,max,20);
    label[9]->setText( i18n("MIME types:" ));
    lista[0] = new QListBox( w[4], "Tipos");
    lista[0]->setGeometry(10,30,max,80);
    lista[0]->setMultiSelection(true);
    lista[0]->insertItem("x-msvideo (*.avi)");
    lista[0]->insertItem("quicktime (*.mov *.moov *.qt *.hqx)");
    lista[0]->insertItem("mpeg (*.mpg)");
    lista[0]->insertItem("x-flic (*.fli *.flc)");

    registerButton = new QPushButton( w[4], "registerButton");
    registerButton->setText( i18n("&Register types"));
    registerButton->setGeometry(10,120,100,30);
    connect( registerButton, SIGNAL(clicked()), SLOT(mimeRegister()) );

    w[4]->resize( max+10, may );
    tab->addTab( w[4], "MIME");
*/

    quitButton = new QPushButton( this, "cancelButton" );
    quitButton->setText( i18n("&Cancel") );
    quitButton->setGeometry( 275,may+25, 65,30 );
    connect( quitButton, SIGNAL(clicked()), SLOT(quit()) );
    
    okButton = new QPushButton( this, "OKButton" );
    okButton->setText( i18n("&Ok" ));
    okButton->setGeometry( 190,may+25, 65,30 );
    connect( okButton, SIGNAL(clicked()), SLOT(save()) );
}

void Setup::quit()
{
    done(0);
}

void Setup::save()
{
    config->setGroup("audio");
    config->writeEntry("enable",checkBox[0]->isChecked() );
    config->writeEntry("audioSync",checkBox[1]->isChecked() );
    config->writeEntry("showVolumeSlider",checkBox[8]->isChecked() );
    config->writeEntry("audioInitialVolume",spin[0]->getValue() );

    config->setGroup("color");
    config->writeEntry("colorAhead", lined[0]->text() );
    if (botonRadio[0]->isChecked()) config->writeEntry("colorMapping", 0);
    if (botonRadio[1]->isChecked()) config->writeEntry("colorMapping", 1);
    if (botonRadio[2]->isChecked()) config->writeEntry("colorMapping", 2);
    if (botonRadio[3]->isChecked()) config->writeEntry("colorMapping", 3);
    config->writeEntry("gammaDisp",lined[1]->text() );

    config->setGroup("scaling");
    config->writeEntry("scale",combo[0]->currentItem() );

    config->setGroup("others");
    config->writeEntry("preload",checkBox[2]->isChecked() );
    config->writeEntry("x11shared",checkBox[3]->isChecked() );
    config->writeEntry("multiBuffer",checkBox[4]->isChecked() );
    config->writeEntry("pixmap",checkBox[5]->isChecked() );
//    config->writeEntry("visualClass",combo[0]->currentItem() );
    config->writeEntry("initialDirectory", lined[3]->text() );
    config->writeEntry("loop",checkBox[6]->isChecked() );
    config->writeEntry("extras",lined[2]->text());
    config->writeEntry("autoplay",checkBox[7]->isChecked() );

    config->sync();
    done(1);
}

Setup::~Setup()
{
/*    int x;
    
    for (x=0;x<4;x++) delete lined[x];
    for (x=0;x<9;x++) delete checkBox[x];
    for (x=0;x<4;x++) delete botonRadio[x];
    for (x=0;x<9;x++) delete label[x];
    for (x=0;x<1;x++) delete botones[x];
    for (x=0;x<2;x++) delete zoom[x];
    for (x=0;x<1;x++) delete combo[x];
    for (x=0;x<1;x++) delete spin[x];
    for (x=0;x<3;x++) delete grupo[x];
    for (x=0;x<4;x++) delete w[x];
    delete tab;
    delete quitButton;
    delete okButton;*/
}

void Setup::getDir()
{
   QString s;
   
   s=KFileDialog::getDirectory("",0L);
   if (!s.isEmpty())
      lined[3]->setText(s);
}

#include "aktionConf.moc"
